import { FC, ReactNode } from 'react';
import { FoundationContext } from './types';
export declare const FoundationContextProvider: FC<FoundationContext & {
    children?: ReactNode | Array<ReactNode>;
}>;
export declare const useFoundationContext: () => FoundationContext | undefined;
/**
 * Mainly for docs purposes - sometimes we need to show how components work without contextual defaults
 */
export declare const FoundationContextReset: <Props>(props: Props) => JSX.Element;
/**
 * Allows to integrate the component with foundation context by creating component props default values from context using provided mapping.
 * @returns hook that accepts directly passed component props and provides final component props and props that should be given to inner context.
 * @param contextToProps maps current context into default component properties.
 * @param propsToInnerContext maps final component props into context that can be provided for component children.
 * @param defaultProps component default props when context is not provided
 **/
export declare const createUseFoundationHook: <P>(contextToProps: (context: FoundationContext) => Required<P>, propsToInnerContext: (props: Required<P>) => FoundationContext, defaultProps: Required<P>) => {
    useFoundation: (props: P) => {
        componentProps: NonNullable<Required<P> & P>;
        innerContextProps: FoundationContext;
    };
};
